pub struct ArtifactInfo {
pub path: String,
pub file_name: String,
pub format: ObjectFormat,
pub architecture: String,
pub pointer_width: Option<u8>,
pub size_bytes: u64,
}Fields
path: Stringfile_name: Stringformat: ObjectFormatarchitecture: Stringpointer_width: Option<u8>size_bytes: u64Trait Implementations
Sourceimpl Clone for ArtifactInfo
impl Clone for ArtifactInfo
Sourcefn clone(&self) -> ArtifactInfo
fn clone(&self) -> ArtifactInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArtifactInfo
impl Debug for ArtifactInfo
Sourceimpl<'de> Deserialize<'de> for ArtifactInfo
impl<'de> Deserialize<'de> for ArtifactInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArtifactInfo
impl JsonSchema for ArtifactInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ArtifactInfo
impl RefUnwindSafe for ArtifactInfo
impl Send for ArtifactInfo
impl Sync for ArtifactInfo
impl Unpin for ArtifactInfo
impl UnsafeUnpin for ArtifactInfo
impl UnwindSafe for ArtifactInfo