pub struct BuildInfo {
pub workspace_root: Option<String>,
pub package: Option<String>,
pub profile: Option<String>,
pub target: Option<String>,
pub features: Vec<String>,
pub exact_mode: ExactMode,
}Fields
workspace_root: Option<String>package: Option<String>profile: Option<String>target: Option<String>features: Vec<String>exact_mode: ExactModeTrait Implementations
Sourceimpl<'de> Deserialize<'de> for BuildInfo
impl<'de> Deserialize<'de> for BuildInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BuildInfo
impl JsonSchema for BuildInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BuildInfo
impl RefUnwindSafe for BuildInfo
impl Send for BuildInfo
impl Sync for BuildInfo
impl Unpin for BuildInfo
impl UnsafeUnpin for BuildInfo
impl UnwindSafe for BuildInfo