pub struct EdgeReport {
pub caller: u32,
pub callee: Option<u32>,
pub target_address: Option<u64>,
pub kind: EdgeKind,
pub confidence: Confidence,
}Fields
caller: u32callee: Option<u32>target_address: Option<u64>kind: EdgeKindconfidence: ConfidenceTrait Implementations
Sourceimpl Clone for EdgeReport
impl Clone for EdgeReport
Sourcefn clone(&self) -> EdgeReport
fn clone(&self) -> EdgeReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EdgeReport
impl Debug for EdgeReport
Sourceimpl<'de> Deserialize<'de> for EdgeReport
impl<'de> Deserialize<'de> for EdgeReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EdgeReport
impl JsonSchema for EdgeReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EdgeReport
impl RefUnwindSafe for EdgeReport
impl Send for EdgeReport
impl Sync for EdgeReport
impl Unpin for EdgeReport
impl UnsafeUnpin for EdgeReport
impl UnwindSafe for EdgeReport