pub struct GroupReport {
pub id: u32,
pub name: String,
pub parent: Option<u32>,
pub symbol_ids: Vec<u32>,
pub own_frame_sum: Option<u64>,
pub worst_path_max: Option<u64>,
}Fields
id: u32name: Stringparent: Option<u32>symbol_ids: Vec<u32>own_frame_sum: Option<u64>worst_path_max: Option<u64>Trait Implementations
Sourceimpl Clone for GroupReport
impl Clone for GroupReport
Sourcefn clone(&self) -> GroupReport
fn clone(&self) -> GroupReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GroupReport
impl Debug for GroupReport
Sourceimpl<'de> Deserialize<'de> for GroupReport
impl<'de> Deserialize<'de> for GroupReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GroupReport
impl JsonSchema for GroupReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GroupReport
impl RefUnwindSafe for GroupReport
impl Send for GroupReport
impl Sync for GroupReport
impl Unpin for GroupReport
impl UnsafeUnpin for GroupReport
impl UnwindSafe for GroupReport