pub struct StackwiseReport {
pub schema_version: String,
pub generator: GeneratorInfo,
pub artifact: ArtifactInfo,
pub build: Option<BuildInfo>,
pub summary: Summary,
pub symbols: Vec<SymbolReport>,
pub edges: Vec<EdgeReport>,
pub groups: Vec<GroupReport>,
pub diagnostics: Vec<Diagnostic>,
}Fields
schema_version: Stringgenerator: GeneratorInfoartifact: ArtifactInfobuild: Option<BuildInfo>summary: Summarysymbols: Vec<SymbolReport>edges: Vec<EdgeReport>groups: Vec<GroupReport>diagnostics: Vec<Diagnostic>Trait Implementations
Sourceimpl Clone for StackwiseReport
impl Clone for StackwiseReport
Sourcefn clone(&self) -> StackwiseReport
fn clone(&self) -> StackwiseReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StackwiseReport
impl Debug for StackwiseReport
Sourceimpl<'de> Deserialize<'de> for StackwiseReport
impl<'de> Deserialize<'de> for StackwiseReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StackwiseReport
impl JsonSchema for StackwiseReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StackwiseReport
impl RefUnwindSafe for StackwiseReport
impl Send for StackwiseReport
impl Sync for StackwiseReport
impl Unpin for StackwiseReport
impl UnsafeUnpin for StackwiseReport
impl UnwindSafe for StackwiseReport