pub struct Summary {
pub symbol_count: usize,
pub edge_count: usize,
pub known_frame_count: usize,
pub unknown_frame_count: usize,
pub recursive_symbol_count: usize,
pub indirect_edge_count: usize,
pub max_own_frame: Option<SymbolMetric>,
pub max_worst_path: Option<SymbolMetric>,
pub confidence: Confidence,
}Fields
symbol_count: usizeedge_count: usizeknown_frame_count: usizeunknown_frame_count: usizerecursive_symbol_count: usizeindirect_edge_count: usizemax_own_frame: Option<SymbolMetric>max_worst_path: Option<SymbolMetric>confidence: ConfidenceTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Summary
impl<'de> Deserialize<'de> for Summary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Summary
impl JsonSchema for Summary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Summary
impl RefUnwindSafe for Summary
impl Send for Summary
impl Sync for Summary
impl Unpin for Summary
impl UnsafeUnpin for Summary
impl UnwindSafe for Summary