pub struct SymbolMetric {
pub symbol_id: u32,
pub bytes: u64,
pub demangled: String,
}Fields
symbol_id: u32bytes: u64demangled: StringTrait Implementations
Sourceimpl Clone for SymbolMetric
impl Clone for SymbolMetric
Sourcefn clone(&self) -> SymbolMetric
fn clone(&self) -> SymbolMetric
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SymbolMetric
impl Debug for SymbolMetric
Sourceimpl<'de> Deserialize<'de> for SymbolMetric
impl<'de> Deserialize<'de> for SymbolMetric
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SymbolMetric
impl JsonSchema for SymbolMetric
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SymbolMetric
impl RefUnwindSafe for SymbolMetric
impl Send for SymbolMetric
impl Sync for SymbolMetric
impl Unpin for SymbolMetric
impl UnsafeUnpin for SymbolMetric
impl UnwindSafe for SymbolMetric