pub struct SymbolReport {Show 14 fields
pub id: u32,
pub name: String,
pub demangled: String,
pub crate_name: Option<String>,
pub module_path: Vec<String>,
pub address: u64,
pub size_bytes: Option<u64>,
pub source_location: Option<SourceLocation>,
pub object_format: ObjectFormat,
pub own_frame: FrameInfo,
pub worst_path: WorstPathInfo,
pub confidence: Confidence,
pub evidence: Vec<Evidence>,
pub unresolved_reasons: Vec<UnresolvedReason>,
}Fields
id: u32name: Stringdemangled: Stringcrate_name: Option<String>module_path: Vec<String>address: u64size_bytes: Option<u64>source_location: Option<SourceLocation>object_format: ObjectFormatown_frame: FrameInfoworst_path: WorstPathInfoconfidence: Confidenceevidence: Vec<Evidence>unresolved_reasons: Vec<UnresolvedReason>Trait Implementations
Sourceimpl Clone for SymbolReport
impl Clone for SymbolReport
Sourcefn clone(&self) -> SymbolReport
fn clone(&self) -> SymbolReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SymbolReport
impl Debug for SymbolReport
Sourceimpl<'de> Deserialize<'de> for SymbolReport
impl<'de> Deserialize<'de> for SymbolReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SymbolReport
impl JsonSchema for SymbolReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SymbolReport
impl RefUnwindSafe for SymbolReport
impl Send for SymbolReport
impl Sync for SymbolReport
impl Unpin for SymbolReport
impl UnsafeUnpin for SymbolReport
impl UnwindSafe for SymbolReport