pub struct WorstPathInfo {
pub bytes: Option<u64>,
pub status: UpperBoundStatus,
pub path: Vec<u32>,
}Fields
bytes: Option<u64>status: UpperBoundStatuspath: Vec<u32>Trait Implementations
Sourceimpl Clone for WorstPathInfo
impl Clone for WorstPathInfo
Sourcefn clone(&self) -> WorstPathInfo
fn clone(&self) -> WorstPathInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorstPathInfo
impl Debug for WorstPathInfo
Sourceimpl<'de> Deserialize<'de> for WorstPathInfo
impl<'de> Deserialize<'de> for WorstPathInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorstPathInfo
impl JsonSchema for WorstPathInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorstPathInfo
impl RefUnwindSafe for WorstPathInfo
impl Send for WorstPathInfo
impl Sync for WorstPathInfo
impl Unpin for WorstPathInfo
impl UnsafeUnpin for WorstPathInfo
impl UnwindSafe for WorstPathInfo